@@ -17,7 +17,7 @@
  * The 0x0? prefix is reserved for eztrace internal use. Thus you can
  * use any prefix between 0x10 and 0xff.
  */
-#define EXAMPLE_EVENTS_ID    0x11
+#define EXAMPLE_EVENTS_ID    USER_MODULE_ID(0x11)
 #define EXAMPLE_PREFIX       (EXAMPLE_EVENTS_ID << NB_BITS_EVENTS)
 
 /* Define various event codes used by the example module
