@@ -11,8 +11,17 @@
 #define NB_BITS_PREFIX 8
 #define NB_BITS_EVENTS (NB_BITS - NB_BITS_PREFIX)
 
+#define SYSTEM_MODULE_MASK (0<<(NB_BITS_PREFIX-1))
+#define USER_MODULE_MASK (1<<(NB_BITS_PREFIX-1))
+
+#define USER_MODULE_ID(id)   (id | USER_MODULE_MASK)
+#define SYSTEM_MODULE_ID(id) (id | SYSTEM_MODULE_MASK)
+
+#define GENERATE_USER_MODULE_PREFIX(id)   ((id) << NB_BITS_EVENTS)
+#define GENERATE_SYSTEM_MODULE_PREFIX(id) ((id) << NB_BITS_EVENTS)
+
 #define PTHREAD_CORE_EVENTS_ID 0x00
-#define PTHREAD_CORE_PREFIX    (PTHREAD_CORE_EVENTS_ID << NB_BITS_EVENTS)
+#define PTHREAD_CORE_PREFIX    GENERATE_SYSTEM_MODULE_PREFIX(PTHREAD_CORE_EVENTS_ID)
 
 /* thread creation/destruction */
 #define FUT_NEW_THREAD          (PTHREAD_CORE_PREFIX | 0x0001)
