@@ -51,6 +51,35 @@ void eztrace_convert_init(unsigned __nb_traces)
   traces = malloc(sizeof(struct trace_t) * __nb_traces);
 }
 
+void eztrace_initialize_gtg()
+{
+  /* the thread is waiting for something (sem_P, mutex_lock, etc.) */
+  addContType("CT_Program", NULL, "Program");
+  addContType("CT_Process", "CT_Program", "Process");
+  addContType("CT_Thread", "CT_Process", "Thread");
+
+  addStateType("ST_Program", "CT_Program", "Program state");
+  addStateType("ST_Process", "CT_Process", "Process state");
+  addStateType("ST_Thread", "CT_Thread", "Thread state");
+
+  /* the thread is blocked */
+  addEntityValue("STV_FLUSH", "ST_Thread", "EZTrace Flush", GTG_WHITE);
+
+  /* the thread is blocked */
+  addEntityValue("STV_Blocked", "ST_Thread", "Blocked", GTG_RED);
+  /* the thread is computing */
+  addEntityValue("STV_Working", "ST_Thread", "Working", GTG_BLUE);
+  /* the thread is within a critical section (mutex, spinlock, ...) */
+  addEntityValue("STV_Critical", "ST_Thread", "Critical Section", GTG_GREEN);
+
+  addEntityValue("STV_EZTRACE_SYNC", "ST_Thread", "EZTrace synchronization", GTG_WHITE);
+
+  addEventType("E_SigSegv", "CT_Thread", "SIGNAL Received");
+
+  addContainer (0.00000, "C_Prog", "CT_Program", NULL, "Program", "0");
+}
+
+
 struct eztrace_event_handler* get_handler_info()
 {
   return &__handler_info;
@@ -284,7 +313,8 @@ handle_end_thread (void)
   FUNC_NAME;
 
   DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
-  if(__cur_mode == EZTRACE_CONVERT) {
+  if(__cur_mode == EZTRACE_CONVERT && thread_id) {
+
     destroyContainer(CURRENT, thread_id, "CT_Thread");
   }
 }
@@ -342,6 +372,20 @@ handle_signal()
   free(event_str);
 }
 
+uint64_t add_delay_to_trace(int trace_num, uint64_t old_time, uint64_t new_time, const char* thread_id)
+{
+    struct trace_t* t = get_traces(trace_num);
+    uint64_t delay = new_time - old_time;
+
+    t->delay += delay;
+
+    CHANGE() pushState(old_time/1000000.0, "ST_Thread", thread_id, "STV_EZTRACE_SYNC");
+
+    CHANGE() popState(new_time/1000000.0, "ST_Thread", thread_id);
+
+    return delay;
+}
+
 
 
 static struct ezt_list_t module_list;
@@ -676,6 +720,19 @@ eztrace_mode_t get_mode()
   return __cur_mode;
 }
 
+void handle_start_flush()
+{
+  FUNC_NAME;
+  DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
+  CHANGE() pushState(CURRENT, "ST_Thread", thread_id, "STV_FLUSH");
+}
+
+void handle_stop_flush()
+{
+  FUNC_NAME;
+  DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
+  CHANGE() popState(CURRENT, "ST_Thread", thread_id);
+}
 
 int process_one_event(struct fxt_ev_64 *ev)
 {
@@ -699,6 +756,15 @@ int process_one_event(struct fxt_ev_64 *ev)
 	ret = 1;
 	break;
 
+      case FUT_START_FLUSH_CODE:
+	handle_start_flush();
+	ret = 1;
+	break;
+      case FUT_STOP_FLUSH_CODE:
+	handle_stop_flush();
+	ret = 1;
+	break;
+
 	/* Handle the pthread_core related codes */
       case FUT_NEW_THREAD:
 	/* already processed by the main thread, we can ignore this event */
@@ -729,8 +795,8 @@ int process_one_event(struct fxt_ev_64 *ev)
 
   if(!ret && NB_START >= NB_TRACES) {
     /* This event is unknown :-( */
-    fprintf (stderr, "unknown event.. %x at time %llu\n",
-	     (unsigned) ev->code, (long long unsigned) ev->time);
+    fprintf (stderr, "[%d] unknown event.. %x at time %llu\n",
+	     CUR_INDEX, (unsigned) ev->code, (long long unsigned) ev->time);
   }
   return ret;
 }
@@ -817,6 +883,56 @@ int stats_handle_events(struct fxt_ev_64 *ev)
   return __handle_event_generic(ev);
 }
 
+
+/* ask the event scheduler to call handle(data) next time trace #trace_index is scheduled */
+void ask_for_replay(int trace_index,
+		    void (*handle)(void*),
+		    void* data);
+
+struct __ezt_replay{
+  void (*handle)(void*);
+  void* data;
+};
+
+struct __ezt_replay *replays = NULL;
+
+/* ask the event scheduler to call handle(data) next time trace #trace_index is scheduled
+ * see handle_mpi_stop_waitall in src/modules/mpi/eztrace_convert_mpi.c for an example
+ */
+void ask_for_replay(int trace_index,
+		    void (*handle)(void*),
+		    void* data)
+{
+  if(!replays) {
+    /* first time this function is called. allocate replays */
+    int nb_traces = *(get_nb_traces());
+    replays = malloc(sizeof(struct __ezt_replay) * nb_traces);
+    int i;
+    for(i=0; i< nb_traces; i++){
+      replays[i].handle = NULL;
+      replays[i].data = NULL;
+    }
+  }
+
+  assert(replays[trace_index].handle == NULL);
+  replays[trace_index].handle = handle;
+  replays[trace_index].data = data;
+}
+
+/* execute a replay */
+static void __execute_replay(struct __ezt_replay *r)
+{
+  void (*handle)(void*) = r->handle;
+  void* data = r->data;
+
+  /* remove the replay so that we don't loop infinitely */
+  r->handle = NULL;
+  r->data = NULL;
+
+  /* execute the function */
+  handle(data);
+}
+
 void* handle_one_event(void* arg)
 {
   /* get the next event to process */
@@ -825,8 +941,18 @@ void* handle_one_event(void* arg)
   set_cur_ev(&get_cur_trace()->ev);
 
   int ret = 0;
-  ret = handle_event(CUR_EV);
-  __handler_info.nb_handled += ret;
+  if(replays && replays[__handler_info.cur_trace_nb].handle) {
+    /* execute the replay */
+
+    __execute_replay(&replays[__handler_info.cur_trace_nb]);
+
+  } else {
+
+    
+    ret = (__cur_mode == EZTRACE_CONVERT)? handle_event(CUR_EV) : stats_handle_events(CUR_EV);
+    __handler_info.nb_handled += ret;
+
+  }
 
   /* If current event was skipped, do not step forward the trace or this event will be 'lost' */
   if( !SKIP && !next_ev(__handler_info.cur_trace_nb))
