@@ -10,8 +10,8 @@
 #include "ev_codes.h"
 
 
-#define MEMORY_EVENTS_ID 0x05
-#define MEMORY_PREFIX    (MEMORY_EVENTS_ID << NB_BITS_EVENTS)
+#define MEMORY_EVENTS_ID SYSTEM_MODULE_ID(0x05)
+#define MEMORY_PREFIX    GENERATE_SYSTEM_MODULE_PREFIX(MEMORY_EVENTS_ID)
 
 #define FUT_MEMORY_MALLOC    (MEMORY_PREFIX | 0X0001)
 #define FUT_MEMORY_CALLOC    (MEMORY_PREFIX | 0X0002)
