@@ -28,25 +28,22 @@ void __print_coll_message(FILE*stream, struct mpi_coll_msg_t *msg);
 void __print_coll_messages_recurse(FILE*stream, unsigned depth, p_eztrace_container p_cont);
 void __print_coll_messages(FILE*stream);
 
-struct mpi_coll_msg_t* __new_coll_message(char* id,
-					  enum coll_type_t type,
-					  int comm_size,
-					  int len);
-
 struct mpi_coll_msg_t*
 __enter_coll(uint64_t time,
 	     enum coll_type_t type,
-	     int comm_size,
+	     struct ezt_mpi_comm *comm,
 	     int my_rank,
 	     int len,
+	     struct mpi_request *req,
 	     char* thread_id);
 
 struct mpi_coll_msg_t*
 __leave_coll(uint64_t time,
 	     enum coll_type_t type,
-	     int comm_size,
+	     struct ezt_mpi_comm *comm,
 	     int my_rank,
 	     int len,
+	     struct mpi_request *req,
 	     char* thread_id);
 
 
