@@ -9,11 +9,12 @@
 #include "eztrace_convert_mpi.h"
 #include "eztrace_hierarchical_array.h"
 
-
+#if 0
 /* Value of MPI_ANY_SOURCE */
 extern int __MPI_ANY_SOURCE;
 /* Value of MPI_ANY_TAG */
 extern uint32_t __MPI_ANY_TAG;
+#endif
 
 enum pending_comm_status_t {
   NONE_DONE = 1,
@@ -29,39 +30,6 @@ struct mpi_pending_comm {
   enum pending_comm_status_t status;
 };
 
-enum comm_type_t {
-  comm_type_incoming= 0,   /* pending recv */
-  comm_type_outgoing= 1,   /* pending send */
-  comm_type_max  = 2,
-};
-
-/* Each process has a list of pending isend/irecv */
-struct mpi_process_info_t {
-  struct ezt_list_t pending_comm[comm_type_max];
-  struct process_info_t *p_process;
-};
-
-
-/* attach process-specific data to a process when it's created */
-static struct mpi_process_info_t* __register_process_hook(struct process_info_t* p_process)
-{
-  struct mpi_process_info_t *p_info = (struct mpi_process_info_t*) malloc(sizeof(struct mpi_process_info_t));
-  p_info->p_process = p_process;
-  int i;
-  for(i=0; i<comm_type_max; i++)
-    ezt_list_new(&p_info->pending_comm[i]);
-
-  /* add the hook in the thread info structure */
-  ezt_hook_list_add(&p_info->p_process->hooks, p_info, (uint8_t)MPI_EVENTS_ID);
-  return p_info;
-}
-
-#define  INIT_MPI_PROCESS_INFO(p_process, var)				\
-  struct mpi_process_info_t *var = (struct mpi_process_info_t*)		\
-    ezt_hook_list_retrieve_data(&p_process->hooks, (uint8_t)MPI_EVENTS_ID); \
-  if(!(var)) {								\
-    var = __register_process_hook(p_process);				\
-  }
 
 void init_mpi_p2p_messages() {
   hierarchical_array_attach(MPI_P2P_ID, sizeof(struct mpi_p2p_msg_t));
@@ -213,7 +181,7 @@ struct mpi_request* __mpi_new_mpi_request(int rank,
 					  app_ptr mpi_req,
 					  enum mpi_request_type req_type)
 {
-  struct eztrace_container_t* container = GET_PROCESS_CONTAINER(rank);
+  struct eztrace_container_t* container = GET_PROCESS_CONTAINER(rank_to_trace_id[rank]);
   struct mpi_request* req = hierarchical_array_new_item(container, MPI_REQUEST_ID);
   assert(req);
 
@@ -232,7 +200,7 @@ __mpi_find_mpi_req(int rank,
 		   enum mpi_request_type req_type)
 {
   struct hierarchical_array *array = hierarchical_array_find(MPI_REQUEST_ID,
-							     GET_PROCESS_CONTAINER(rank));
+							     GET_PROCESS_CONTAINER(rank_to_trace_id[rank]));
   assert(array);
 
   int index;
@@ -301,6 +269,8 @@ __mpi_find_p2p_message(int src __attribute__((unused)),
 		       uint32_t tag,
 		       int time_id)
 {
+  INIT_MPI_PROCESS_INFO(GET_PROCESS_INFO(dest), p_info);
+
   struct hierarchical_array* array = hierarchical_array_find(MPI_P2P_ID, GET_PROCESS_CONTAINER(dest));
   struct mpi_p2p_msg_t* msg = NULL;
   int index;
@@ -309,9 +279,9 @@ __mpi_find_p2p_message(int src __attribute__((unused)),
   for(index = (array->nb_items)-1; index>=0; index--) {
     msg = ITH_ITEM(index, array);
 
-    if(((msg->src == src) || (msg->src == __MPI_ANY_SOURCE)) &&
+    if(((msg->src == src) || (msg->src == p_info->__MPI_ANY_SOURCE)) &&
        (msg->dest == dest) &&
-       ((msg->tag == tag) || (msg->tag == __MPI_ANY_TAG)) &&
+       ((msg->tag == tag) || (msg->tag == p_info->__MPI_ANY_TAG)) &&
        (time_id<0 ||!msg->times[time_id])) {
       return msg;
     }
@@ -326,23 +296,25 @@ __mpi_find_p2p_message(int src __attribute__((unused)),
 struct mpi_pending_comm*
 __mpi_p2p_find_pending_comm(int src,
 			    int dest,
-			    int len,
+			    int len __attribute__((unused)),
 			    uint32_t tag,
 			    enum comm_type_t type,
 			    uint32_t mask_ok,
 			    uint32_t mask_not_ok)
 {
   struct mpi_process_info_t * process_info = NULL;
+
+  INIT_MPI_PROCESS_INFO(GET_PROCESS_INFO(dest), p_info);
+
   switch (type) {
   case comm_type_outgoing:
     {
-      INIT_MPI_PROCESS_INFO(GET_PROCESS_INFO(src), p_info);
-      process_info=p_info;
+      INIT_MPI_PROCESS_INFO(GET_PROCESS_INFO(src), p_info_src);
+      process_info=p_info_src;
     }
     break;
   case comm_type_incoming:
     {
-      INIT_MPI_PROCESS_INFO(GET_PROCESS_INFO(dest), p_info);
       process_info=p_info;
     }
     break;
@@ -350,6 +322,7 @@ __mpi_p2p_find_pending_comm(int src,
     assert(1);
   }
 
+
   struct mpi_p2p_msg_t* msg = NULL;
   struct ezt_list_token_t *token;
 
@@ -360,8 +333,8 @@ __mpi_p2p_find_pending_comm(int src,
     msg = p_comm->msg;
 
     if((msg->dest == dest) &&
-       ((msg->src == src) || (msg->src == __MPI_ANY_SOURCE) || (src == __MPI_ANY_SOURCE)) &&
-       ((msg->tag == tag) || (msg->tag == __MPI_ANY_TAG) || (tag == __MPI_ANY_TAG)) &&
+       ((msg->src == src) || (msg->src == p_info->__MPI_ANY_SOURCE) || (src == p_info->__MPI_ANY_SOURCE)) &&
+       ((msg->tag == tag) || (msg->tag == p_info->__MPI_ANY_TAG) || (tag == p_info->__MPI_ANY_TAG)) &&
        (p_comm->status & mask_ok) &&
        (!(p_comm->status & mask_not_ok))) {
 
@@ -394,7 +367,8 @@ __mpi_p2p_find_pending_isend(int src,
 			     uint32_t mask_ok,
 			     uint32_t mask_not_ok)
 {
-  if(src == __MPI_ANY_SOURCE){
+  INIT_MPI_PROCESS_INFO(GET_PROCESS_INFO(dest), p_info);
+  if(src == p_info->__MPI_ANY_SOURCE){
     /* In case of any_source, we don't know where to search for the isend,
      * so we need to find the message first
      */
@@ -523,6 +497,13 @@ __stop_recv_message(uint64_t stop_time,
   struct mpi_pending_comm* pending_comm_outgoing = NULL;
   assert(pending_comm);
 
+
+  if(!(pending_comm->status & ISEND_DONE))
+    /* the matching isend has not happened yet. This means there's a synchronisation problem
+     * between the traces.
+     */
+     return NULL;
+
   /* update the status of the pending incoming comm */
   pending_comm->status |= RWAIT_DONE;
   msg = pending_comm->msg;
@@ -593,6 +574,7 @@ __start_send_message(uint64_t start_time,
   assert(msg);
 
   __record_event(start_time, GET_PROCESS_CONTAINER(dest), MPI_P2P_ISEND_ID, msg);
+  INIT_MPI_PROCESS_INFO(GET_PROCESS_INFO(dest), p_info);
 
   msg->sender_thread_id = thread_id;
   msg->sender_request = mpi_req;
@@ -601,6 +583,11 @@ __start_send_message(uint64_t start_time,
   if(mpi_req)
     mpi_req->msg = msg;
 
+ if(msg->src == p_info->__MPI_ANY_SOURCE)
+    msg->src = src;
+  if(msg->tag == p_info->__MPI_ANY_TAG)
+    msg->tag = tag;
+
   if((!msg->id) &&
      msg->sender_thread_id &&
      msg->recver_thread_id) {
@@ -645,9 +632,11 @@ __stop_send_message(uint64_t stop_time,
   assert(msg);
 
   __record_event(stop_time, GET_PROCESS_CONTAINER(dest), MPI_P2P_SWAIT_ID, msg);
-  if(msg->src == __MPI_ANY_SOURCE)
+  INIT_MPI_PROCESS_INFO(GET_PROCESS_INFO(dest), p_info);
+
+  if(msg->src == p_info->__MPI_ANY_SOURCE)
     msg->src = src;
-  if(msg->tag == __MPI_ANY_TAG)
+  if(msg->tag == p_info->__MPI_ANY_TAG)
     msg->tag = tag;
 
   if(!msg->times[start_swait])
