@@ -18,10 +18,6 @@ void init_mpi_stats();
 /* dump to disk the list of messages */
 void mpi_stats_dump();
 
-void mpi_stats_comm_matrix_latex();
-
-void mpi_stats_comm_matrix_xml();
-
 void mpi_stats_plot_message_size();
 
 #endif	/* EZTRACE_STATS_MPI_H */
