@@ -22,7 +22,10 @@
 #include "eztrace.h"
 
 
-static void MPI_Probe_prolog( int source, int tag, MPI_Comm comm, MPI_Status *status )
+static void MPI_Probe_prolog( int source __attribute__((unused)),
+			      int tag __attribute__((unused)),
+			      MPI_Comm comm __attribute__((unused)),
+			      MPI_Status *status __attribute__((unused)) )
 {
   EZTRACE_EVENT0(FUT_MPI_START_PROBE);
 }
@@ -32,7 +35,10 @@ static int MPI_Probe_core( int source, int tag, MPI_Comm comm, MPI_Status *statu
   return libMPI_Probe(source, tag, comm, status);
 }
 
-static void MPI_Probe_epilog( int source, int tag, MPI_Comm comm, MPI_Status *status )
+static void MPI_Probe_epilog( int source __attribute__((unused)),
+			      int tag __attribute__((unused)),
+			      MPI_Comm comm __attribute__((unused)),
+			      MPI_Status *status )
 {
   int length = -1;
   MPI_Get_count(status, MPI_BYTE, &length);
