@@ -23,11 +23,14 @@
 
 
 
-static void MPI_Startall_prolog(int count, MPI_Fint *req)
+static void MPI_Startall_prolog(int count, void*req, size_t size)
 {
  int i;
-  for(i=0; i<count; i++)
-    EZTRACE_EVENT1(FUT_MPI_START, req[i]);
+ for(i=0; i<count; i++)
+    /* we can't use &req[i] here since req may be an array of MPI_Request or MPI_Fint
+     * (which may have different size)
+     */
+   EZTRACE_EVENT1(FUT_MPI_START, (void*)req + (i*size));
 }
 
 static int MPI_Startall_core(int count, MPI_Request *req)
@@ -40,7 +43,7 @@ int MPI_Startall(int count, MPI_Request *req)
 {
   FUNCTION_ENTRY;
 
-  MPI_Startall_prolog(count, req);
+  MPI_Startall_prolog(count, req, sizeof(MPI_Request));
   int ret = MPI_Startall_core(count, req);
 
   return ret;
@@ -55,7 +58,7 @@ void mpif_startall_(int*count, MPI_Fint *reqs, int*error)
   for(i=0; i<*count;i++)
     p_req[i] = MPI_Request_f2c(reqs[i]);
 
-  MPI_Startall_prolog(*count, reqs);
+  MPI_Startall_prolog(*count, reqs, sizeof(MPI_Fint));
   *error = MPI_Startall_core(*count, p_req);
 
   for(i=0; i<*count;i++)
