@@ -27,7 +27,7 @@ static int MPI_Test_core(MPI_Request *req, int *a, MPI_Status *s)
   return libMPI_Test(req, a, s);
 }
 
-static void MPI_Test_epilog(MPI_Fint *req, int *a, MPI_Status *s)
+static void MPI_Test_epilog(MPI_Fint *req, int *a, MPI_Status *s __attribute__((unused)))
 {
   if (*a)
     EZTRACE_EVENT1(FUT_MPI_TEST_SUCCESS, req);
@@ -38,7 +38,7 @@ int MPI_Test(MPI_Request *req, int *a, MPI_Status *s)
 {
   FUNCTION_ENTRY;
   int res = MPI_Test_core(req, a, s);
-  MPI_Test_epilog(req, a, s);
+  MPI_Test_epilog((MPI_Fint*)req, a, s);
   return res;
 }
 
