@@ -27,12 +27,16 @@ static int MPI_Testall_core (int count, MPI_Request *reqs, int *flag, MPI_Status
   return libMPI_Testall(count, reqs, flag, s);
 }
 
-static void MPI_Testall_epilog (int count, MPI_Fint *reqs, int *flag, MPI_Status *s)
+static void MPI_Testall_epilog (int count,
+				MPI_Fint *reqs,
+				int *flag,
+				MPI_Status *s __attribute__((unused)),
+				size_t size)
 {
   if(*flag) {
     int i;
     for(i=0; i<count; i++)
-      EZTRACE_EVENT1(FUT_MPI_TEST_SUCCESS, reqs[i]);
+      EZTRACE_EVENT1(FUT_MPI_TEST_SUCCESS, (void*)reqs + (i*size));
   }
 }
 
@@ -40,7 +44,7 @@ int MPI_Testall (int count, MPI_Request *reqs, int *flag, MPI_Status *s)
 {
   FUNCTION_ENTRY;
   int ret = MPI_Testall_core(count, reqs, flag, s);
-  MPI_Testall_epilog(count, reqs, flag, s);
+  MPI_Testall_epilog(count, reqs, flag, s, sizeof(MPI_Request));
 
   return ret;
 }
@@ -57,6 +61,6 @@ void mpif_testall_(int *count, MPI_Fint *r, int *index, MPI_Status *s, int *erro
   for(i=0; i<*count;i++)
     r[i]= MPI_Request_c2f(p_req[i]);
 
-  MPI_Testall_epilog(*count, r, index, s);
+  MPI_Testall_epilog(*count, r, index, s, sizeof(MPI_Fint));
   FREE_ITEMS(*count, p_req);
 }
