@@ -26,10 +26,15 @@ static int MPI_Testany_core (int count, MPI_Request *reqs, int *index, int *flag
   return libMPI_Testany(count, reqs, index, flag, status);
 }
 
-static void MPI_Testany_epilog (int count, MPI_Request *reqs, int *index, int *flag, MPI_Status *status)
+static void MPI_Testany_epilog (int count __attribute__((unused)),
+				void *reqs,
+				int *index,
+				int *flag,
+				MPI_Status *status __attribute__((unused)),
+				size_t size)
 {
   if(*flag)
-    EZTRACE_EVENT1(FUT_MPI_TEST_SUCCESS, &reqs[*index]);
+    EZTRACE_EVENT1(FUT_MPI_TEST_SUCCESS, (void*)reqs + ((*index)*size));
 }
 
 
@@ -37,7 +42,7 @@ int MPI_Testany (int count, MPI_Request *reqs, int *index, int *flag, MPI_Status
 {
   FUNCTION_ENTRY;
   int ret = MPI_Testany_core(count, reqs, index, flag, status);
-  MPI_Testany_epilog(count, reqs, index, flag, status);
+  MPI_Testany_epilog(count, reqs, index, flag, status, sizeof(MPI_Request));
   return ret;
 }
 
@@ -52,6 +57,6 @@ void mpif_testany_(int *count, MPI_Fint *r, int *index, int *flag, MPI_Status *s
   for(i=0; i<*count;i++)
     r[i]= MPI_Request_c2f(p_req[i]);
 
-  MPI_Testany_epilog(*count, r, index, flag, s);
+  MPI_Testany_epilog(*count, r, index, flag, s, sizeof(MPI_Fint));
   FREE_ITEMS(*count, p_req);
 }
