@@ -22,7 +22,7 @@
 #include "eztrace.h"
 
 
-static void MPI_Wait_prolog(MPI_Fint *req, MPI_Status *s)
+static void MPI_Wait_prolog(MPI_Fint *req, MPI_Status *s __attribute__((unused)))
 {
   EZTRACE_EVENT1(FUT_MPI_START_WAIT, req);
 }
@@ -32,7 +32,7 @@ static int MPI_Wait_core(MPI_Request *req, MPI_Status *s)
   return libMPI_Wait(req, s);
 }
 
-static void MPI_Wait_epilog(MPI_Fint *req, MPI_Status *s)
+static void MPI_Wait_epilog(MPI_Fint *req, MPI_Status *s __attribute__((unused)))
 {
   EZTRACE_EVENT1(FUT_MPI_STOP_WAIT, req);
 }
@@ -41,9 +41,9 @@ static void MPI_Wait_epilog(MPI_Fint *req, MPI_Status *s)
 int MPI_Wait(MPI_Request *req, MPI_Status *s)
 {
   FUNCTION_ENTRY;
-  MPI_Wait_prolog(req, s);
+  MPI_Wait_prolog((MPI_Fint*)req, s);
   int ret = MPI_Wait_core(req, s);
-  MPI_Wait_epilog(req, s);
+  MPI_Wait_epilog((MPI_Fint*) req, s);
   return ret;
 }
 
