@@ -2,6 +2,28 @@
 #include <stdlib.h>
 #include <math.h>
 
+#include <stdarg.h>
+
+
+// Debugging part, print out only if debugging level of the system is verbose or more
+int _debug = -77;
+
+void debug(char *fmt, ...)
+{
+	if(_debug == -77) {
+		char *buf = getenv("EZTRACE_DEBUG");
+		if(buf == NULL) _debug = 0;
+		else _debug = atoi(buf);
+	}
+	if(_debug >= 0) { // debug verbose mode
+		va_list va;
+		va_start(va, fmt);
+		vfprintf(stdout, fmt, va);
+		va_end(va);
+	}
+}
+// end of debugging part
+
 #define N 100000
 #define M 10
 
@@ -49,7 +71,7 @@ int main() {
 	r = r+ b[i];
       }
 
-      printf("r = %lf\n", r);
+      debug("r = %lf\n", r);
     }
   }
 
